********
DataTree
********

Inheritance diagram
===================

.. inheritance-diagram:: CGATReport.DataTree
   :parts: 1

cgatreport`DataTree`
=======================

.. automodule:: DataTree
   :members:
   :inherited-members:
   :show-inheritance:



